@@ -13,7 +13,8 @@ from dagster_test.test_project import get_test_project_environments_path
 
 @requires_airflow_db
 def test_my_custom_operator(
-    dagster_airflow_custom_operator_pipeline, caplog,
+    dagster_airflow_custom_operator_pipeline,
+    caplog,
 ):  # pylint: disable=redefined-outer-name
     caplog.set_level(logging.INFO, logger="CustomOperatorLogger")
     pipeline_name = "demo_pipeline"
